searchData={"items":[{"type":"module","title":"Mentor","doc":"The `Mentor` module facilitates interactions with Large Language Models (LLMs) by managing conversation state, configuring adapters, and validating responses against specified schemas.","ref":"Mentor.html"},{"type":"module","title":"Features - Mentor","doc":"- Initiate and manage chat sessions with various LLM adapters.\n- Configure session parameters, including retry limits and debugging options.\n- Validate LLM responses against predefined schemas to ensure data integrity. Supported schemas include `Ecto` schemas, structs, raw maps, `NimbleOptions`, and `Peri` schemas.\n\n> #### Note {: .warning}\n>\n> For now, until `v0.1.0` only `Ecto` shemas are supported.","ref":"Mentor.html#module-features"},{"type":"function","title":"Mentor.append_message/2","doc":"Adds a new message to the conversation history.","ref":"Mentor.html#append_message/2"},{"type":"function","title":"Parameters - Mentor.append_message/2","doc":"- `mentor` - The current `Mentor` struct.\n- `message` - A map representing the message to be added, typically containing:\n  - `:role` - The role of the message sender (e.g., \"user\", \"assistant\", \"system\", \"developer\").\n  - `:content` - The content of the message (e.g. a raw string).","ref":"Mentor.html#append_message/2-parameters"},{"type":"function","title":"Returns - Mentor.append_message/2","doc":"- An updated `Mentor` struct with the new message appended to the `messages` list.","ref":"Mentor.html#append_message/2-returns"},{"type":"function","title":"Examples - Mentor.append_message/2","doc":"iex> mentor = %Mentor{}\n    iex> message = %{role: \"user\", content: \"Hello, assistant!\"}\n    iex> Mentor.append_message(mentor, message)\n    %Mentor{messages: [%{role: \"user\", content: \"Hello, assistant!\"}]}","ref":"Mentor.html#append_message/2-examples"},{"type":"function","title":"Mentor.complete/1","doc":"Completes the interaction by sending the accumulated messages to the LLM adapter and processing the response.","ref":"Mentor.html#complete/1"},{"type":"function","title":"Parameters - Mentor.complete/1","doc":"- `mentor` - The current `Mentor` struct.","ref":"Mentor.html#complete/1-parameters"},{"type":"function","title":"Returns - Mentor.complete/1","doc":"- `{:ok, result}` on successful completion, where `result` is the validated and processed response.\n- `{:error, reason}` on failure, with `reason` indicating the cause of the error.","ref":"Mentor.html#complete/1-returns"},{"type":"function","title":"Examples - Mentor.complete/1","doc":"iex> mentor = %Mentor{adapter: Mentor.LLM.Adapters.OpenAI, __schema__: MySchema, config: [model: \"gpt-4\"]}\n    iex> Mentor.complete(mentor)\n    {:ok, %MySchema{}}\n\n    iex> mentor = %Mentor{adapter: nil, __schema__: MySchema}\n    iex> Mentor.complete(mentor)\n    {:error, :adapter_not_configured}","ref":"Mentor.html#complete/1-examples"},{"type":"function","title":"Mentor.complete!/1","doc":"Same as `complete/1` but it raises an exception if it fails","ref":"Mentor.html#complete!/1"},{"type":"function","title":"Mentor.configure_adapter/2","doc":"Configures the LLM adapter with the given options.","ref":"Mentor.html#configure_adapter/2"},{"type":"function","title":"Parameters - Mentor.configure_adapter/2","doc":"- `mentor` - The current `Mentor` struct.\n- `config` - A keyword list of configuration options for the adapter.","ref":"Mentor.html#configure_adapter/2-parameters"},{"type":"function","title":"Returns - Mentor.configure_adapter/2","doc":"- An updated `Mentor` struct with the merged adapter configuration.","ref":"Mentor.html#configure_adapter/2-returns"},{"type":"function","title":"Examples - Mentor.configure_adapter/2","doc":"iex> mentor = %Mentor{config: [model: \"gpt-3.5\"]}\n    iex> new_config = [temperature: 0.7]\n    iex> Mentor.configure_adapter(mentor, new_config)\n    %Mentor{config: [model: \"gpt-3.5\", temperature: 0.7]}","ref":"Mentor.html#configure_adapter/2-examples"},{"type":"function","title":"Mentor.define_max_retries/2","doc":"Sets the maximum number of retries for validation failures.","ref":"Mentor.html#define_max_retries/2"},{"type":"function","title":"Parameters - Mentor.define_max_retries/2","doc":"- `mentor` - The current `Mentor` struct.\n- `max` - An integer specifying the maximum number of retries.","ref":"Mentor.html#define_max_retries/2-parameters"},{"type":"function","title":"Returns - Mentor.define_max_retries/2","doc":"- An updated `Mentor` struct with the new `max_retries` value.","ref":"Mentor.html#define_max_retries/2-returns"},{"type":"function","title":"Examples - Mentor.define_max_retries/2","doc":"iex> mentor = %Mentor{max_retries: 3}\n    iex> Mentor.define_max_retries(mentor, 5)\n    %Mentor{max_retries: 5}","ref":"Mentor.html#define_max_retries/2-examples"},{"type":"macro","title":"Mentor.is_llm_adapter/1","doc":"","ref":"Mentor.html#is_llm_adapter/1"},{"type":"type","title":"Mentor.message/0","doc":"","ref":"Mentor.html#t:message/0"},{"type":"function","title":"Mentor.overwrite_initial_prompt/2","doc":"Overwrites the initial prompt for the LLM session.","ref":"Mentor.html#overwrite_initial_prompt/2"},{"type":"function","title":"Parameters - Mentor.overwrite_initial_prompt/2","doc":"- `mentor` - The current `Mentor` struct.\n- `initial_prompt` - A string containing the new initial prompt.","ref":"Mentor.html#overwrite_initial_prompt/2-parameters"},{"type":"function","title":"Returns - Mentor.overwrite_initial_prompt/2","doc":"- An updated `Mentor` struct with the new initial prompt, overwritten.","ref":"Mentor.html#overwrite_initial_prompt/2-returns"},{"type":"function","title":"Examples - Mentor.overwrite_initial_prompt/2","doc":"iex> mentor = %Mentor{}\n    iex> new_prompt = \"You are a helpful assistant.\"\n    iex> Mentor.overwrite_initial_prompt(mentor, new_prompt)\n    %Mentor{initial_prompt: \"You are a helpful assistant.\"}","ref":"Mentor.html#overwrite_initial_prompt/2-examples"},{"type":"type","title":"Mentor.schema/0","doc":"","ref":"Mentor.html#t:schema/0"},{"type":"function","title":"Mentor.start_chat_with!/2","doc":"Starts a new interaction pipeline based on a schema.","ref":"Mentor.html#start_chat_with!/2"},{"type":"function","title":"Parameters - Mentor.start_chat_with!/2","doc":"- `adapter` - The LLM adapter module to handle interactions (e.g., `Mentor.LLM.Adapters.OpenAI`).\n- `opts` - A keyword list of options:\n  - `:schema` - The schema module or map defining the expected data structure, required.\n  - `:adapter_config` - Configuration options specific to the adapter, required.\n  - `:max_retries` (optional) - The maximum number of retries for validation failures (default: 3).","ref":"Mentor.html#start_chat_with!/2-parameters"},{"type":"function","title":"Examples - Mentor.start_chat_with!/2","doc":"iex> config = [model: \"gpt-4\", api_key: System.get_env(\"OPENAI_API_KEY\")]\n    iex> Mentor.start_chat_with!(Mentor.LLM.Adapters.OpenAI, schema: MySchema, adapter_config: config)\n    %Mentor{}\n\n    iex> Mentor.start_chat_with!(UnknownLLMAdapter, schema: MySchema)\n    ** (RuntimeError) UnknownLLMAdapter should implement the Mentor.LLM.Adapter behaviour.\n\n    iex> Mentor.start_chat_with!(Mentor.LLM.Adapters.OpenAI, schema: nil)\n    ** (RuntimeError) nil should be a valid schema","ref":"Mentor.html#start_chat_with!/2-examples"},{"type":"type","title":"Mentor.t/0","doc":"Represents the state of a Mentor session.","ref":"Mentor.html#t:t/0"},{"type":"type","title":"Fields - Mentor.t/0","doc":"- `:__schema__` - The schema module or map defining the expected data structure.\n- `:json_schema` - The JSON schema map derived from the schema, used for validation.\n- `:adapter` - The LLM adapter module responsible for handling interactions.\n- `:initial_prompt` - The initial system prompt guiding the LLM's behavior.\n- `:messages` - A list of messages exchanged in the session.\n- `:config` - Configuration options for the adapter.\n- `:max_retries` - The maximum number of retries allowed for validation failures.\n- `:debug` - A boolean flag indicating whether debugging is enabled.\n- `:http_client` - The HTTP Client that implements the `Mentor.HTTPClient.Adapter` behaviour to be used to dispatch HTTP requests to the LLM adapter.","ref":"Mentor.html#t:t/0-fields"},{"type":"module","title":"Mentor.Ecto.JSONSchema","doc":"Helper module to generate JSON Schema based on Ecto schema.\n\nJSON Schema comes in many flavors and different LLMs have different limitations. Currently, this module aims to implement a schema suitable for [OpenAI structured outputs](https://platform.openai.com/docs/guides/structured-outputs/supported-schemas). This type of JSON schema may not be optimal or compatible with other models. Therefore, it's recommended to use this module as a starting point to generate a schema during development.\n\n> #### Warning {: .warning}\n>\n> For the reasons described above, neither backward compatibility nor compatibility with all built-in adapters are goals of this module.","ref":"Mentor.Ecto.JSONSchema.html"},{"type":"function","title":"Mentor.Ecto.JSONSchema.from_ecto_schema/1","doc":"Generates a JSON Schema from an Ecto schema.","ref":"Mentor.Ecto.JSONSchema.html#from_ecto_schema/1"},{"type":"behaviour","title":"Mentor.Ecto.Schema","doc":"Provides functionality to integrate Ecto schemas with the Mentor framework, ensuring that schemas include comprehensive field documentation.\n\nThis module defines a behaviour that requires implementing a `changeset/2` function and utilizes compile-time hooks to verify that all fields in the schema are documented in the module's `@moduledoc`.","ref":"Mentor.Ecto.Schema.html"},{"type":"behaviour","title":"Usage - Mentor.Ecto.Schema","doc":"To use `Mentor.Ecto.Schema` in your Ecto schema module:\n\n    defmodule MyApp.Schema do\n      use Ecto.Schema\n      use Mentor.Ecto.Schema\n\n      import Ecto.Changeset\n\n      @primary_key false\n      embedded_schema do\n        field :name, :string\n        field :age, :integer\n      end\n\n      @impl true\n      def changeset(%__MODULE__{} = source, %{} = attrs) do\n        source\n        |> cast(attrs, [:name, :age])\n        |> validate_required([:name, :age])\n        |> validate_number(:age, less_than: 100, greater_than: 0)\n      end\n    end\n\nEnsure that your module's `@moduledoc` includes a \"Fields\" section documenting each field:\n\n    @moduledoc \"\"\"\n    Schema representing a person.","ref":"Mentor.Ecto.Schema.html#module-usage"},{"type":"behaviour","title":"Fields - Mentor.Ecto.Schema","doc":"- `name`: The name of the person.\n    - `age`: The age of the person.\n    \"\"\"","ref":"Mentor.Ecto.Schema.html#module-fields"},{"type":"callback","title":"Mentor.Ecto.Schema.changeset/2","doc":"","ref":"Mentor.Ecto.Schema.html#c:changeset/2"},{"type":"function","title":"Mentor.Ecto.Schema.validate/2","doc":"Validates the given data against the specified schema by applying the schema's `changeset/2` function.","ref":"Mentor.Ecto.Schema.html#validate/2"},{"type":"function","title":"Parameters - Mentor.Ecto.Schema.validate/2","doc":"- `schema`: The schema module implementing the `Mentor.Ecto.Schema` behaviour.\n- `data`: A map containing the data to be validated.","ref":"Mentor.Ecto.Schema.html#validate/2-parameters"},{"type":"function","title":"Returns - Mentor.Ecto.Schema.validate/2","doc":"- `{:ok, struct}`: If the data is valid and conforms to the schema.\n- `{:error, changeset}`: If the data is invalid, returns the changeset with errors.","ref":"Mentor.Ecto.Schema.html#validate/2-returns"},{"type":"function","title":"Examples - Mentor.Ecto.Schema.validate/2","doc":"iex> data = %{\"name\" => \"Alice\", \"age\" => 30}\n    iex> Mentor.Ecto.Schema.validate(MyApp.Schema, data)\n    {:ok, %MyApp.Schema{name: \"Alice\", age: 30}}\n\n    iex> invalid_data = %{\"name\" => \"Alice\", \"age\" => 150}\n    iex> Mentor.Ecto.Schema.validate(MyApp.Schema, invalid_data)\n    {:error, %Ecto.Changeset{errors: [age: {\"must be less than 100\", [validation: :number, less_than: 100]}]}}","ref":"Mentor.Ecto.Schema.html#validate/2-examples"},{"type":"behaviour","title":"Mentor.Ecto.Type","doc":"`Mentor.Ecto.Type` is a behaviour that lets your implement your own custom `Ecto.Type`\n  that works natively with Instructor.","ref":"Mentor.Ecto.Type.html"},{"type":"behaviour","title":"Example - Mentor.Ecto.Type","doc":"```elixir\ndefmodule MyCustomType do\n  use Ecto.Type\n  use Mentor.Ecto.Type\n\n  # ... See `Ecto.Type` for implementation details\n\n  def to_json_schema do\n    %{\n      type: \"string\",\n      format: \"email\"\n    }\n  end\nend\n```","ref":"Mentor.Ecto.Type.html#module-example"},{"type":"callback","title":"Mentor.Ecto.Type.to_json_schema/0","doc":"","ref":"Mentor.Ecto.Type.html#c:to_json_schema/0"},{"type":"behaviour","title":"Mentor.HTTPClient.Adapter","doc":"Defines the behaviour for HTTP client adapters within the Mentor framework.\n\nThis module specifies a set of callbacks that any HTTP client adapter must implement to integrate seamlessly with Mentor. By adhering to this behaviour, developers can create custom adapters that handle HTTP requests and responses according to their specific requirements.","ref":"Mentor.HTTPClient.Adapter.html"},{"type":"behaviour","title":"Callbacks - Mentor.HTTPClient.Adapter","doc":"- `request/2`: Initiates an HTTP request based on the provided `Mentor` struct and options.\n- `stream/2` (optional): Initiates a streaming HTTP request.\n- `stream/3` (optional): Initiates a streaming HTTP request with a callback for processing each response chunk.","ref":"Mentor.HTTPClient.Adapter.html#module-callbacks"},{"type":"behaviour","title":"Types - Mentor.HTTPClient.Adapter","doc":"- `status`: Represents the HTTP status code as an integer.\n- `headers`: A list of tuples containing header names and values.\n- `body`: The response body as a binary.\n- `response`: The HTTP response, typically represented by `Finch.Response.t()`.","ref":"Mentor.HTTPClient.Adapter.html#module-types"},{"type":"behaviour","title":"Usage - Mentor.HTTPClient.Adapter","doc":"To implement a custom HTTP client adapter, define a module that implements the `Mentor.HTTPClient.Adapter` behaviour:\n\n    defmodule MyApp.HTTPClient.CustomAdapter do\n      @behaviour Mentor.HTTPClient.Adapter\n\n      @impl true\n      def request(%Mentor{} = mentor, opts) do\n        # Implementation for processing the mentor struct and options\n      end\n\n      @impl true\n      def stream(%Mentor{} = mentor, opts) do\n        # Optional implementation for streaming requests\n      end\n\n      @impl true\n      def stream(%Mentor{} = mentor, on_response, opts) do\n        # Optional implementation for streaming requests with a response callback\n      end\n    end\n\nBy implementing these callbacks, your custom adapter can be utilized within the Mentor framework to handle HTTP interactions.","ref":"Mentor.HTTPClient.Adapter.html#module-usage"},{"type":"behaviour","title":"Considerations - Mentor.HTTPClient.Adapter","doc":"- **Optional Callbacks**: The `stream/2` and `stream/3` callbacks are optional. If your adapter does not support streaming, you may omit these implementations.\n- **Error Handling**: Ensure that your adapter appropriately handles errors and returns `{:error, reason}` tuples when necessary.\n- **Integration**: Custom adapters allow Mentor to interface with various HTTP clients, such as [Mint](https://github.com/elixir-mint/mint), [Finch](https://github.com/sneako/finch), or [Tesla](https://github.com/elixir-tesla/tesla), providing flexibility in choosing the underlying HTTP client library.\n\nBy following this behaviour, developers can create flexible and interchangeable HTTP client adapters that integrate seamlessly with the Mentor framework.","ref":"Mentor.HTTPClient.Adapter.html#module-considerations"},{"type":"type","title":"Mentor.HTTPClient.Adapter.body/0","doc":"","ref":"Mentor.HTTPClient.Adapter.html#t:body/0"},{"type":"type","title":"Mentor.HTTPClient.Adapter.headers/0","doc":"","ref":"Mentor.HTTPClient.Adapter.html#t:headers/0"},{"type":"callback","title":"Mentor.HTTPClient.Adapter.request/4","doc":"","ref":"Mentor.HTTPClient.Adapter.html#c:request/4"},{"type":"type","title":"Mentor.HTTPClient.Adapter.request_opts/0","doc":"","ref":"Mentor.HTTPClient.Adapter.html#t:request_opts/0"},{"type":"type","title":"Mentor.HTTPClient.Adapter.status/0","doc":"","ref":"Mentor.HTTPClient.Adapter.html#t:status/0"},{"type":"type","title":"Mentor.HTTPClient.Adapter.url/0","doc":"","ref":"Mentor.HTTPClient.Adapter.html#t:url/0"},{"type":"module","title":"Mentor.HTTPClient.Finch","doc":"An HTTP client adapter for the Mentor framework, utilizing the Finch library for efficient and performant HTTP requests.\n\nThis module implements the `Mentor.HTTPClient.Adapter` behaviour, providing the necessary functions to handle HTTP requests within the Mentor framework using Finch. Finch is an HTTP client focused on performance, built on top of Mint and NimblePool. [oai_citation_attribution:1‡GitHub](https://github.com/sneako/finch?utm_source=chatgpt.com)","ref":"Mentor.HTTPClient.Finch.html"},{"type":"module","title":"Usage - Mentor.HTTPClient.Finch","doc":"To use this adapter, ensure that Finch is started and configured appropriately in your application. Typically, you'll add Finch to your supervision tree:\n\n    children = [\n      {Finch, name: Mentor.Finch}\n    ]\n\nWith Finch running, the `Mentor.HTTPClient.Finch` module can handle HTTP requests as defined by the `Mentor.HTTPClient.Adapter` behaviour.","ref":"Mentor.HTTPClient.Finch.html#module-usage"},{"type":"module","title":"Considerations - Mentor.HTTPClient.Finch","doc":"- **Finch Configuration**: Ensure that Finch is properly configured and started in your application's supervision tree to handle HTTP requests effectively.\n\n- **Request Options**: The `request/2` function accepts a keyword list of options that are passed to Finch's `request/3` function. Refer to Finch's documentation for details on available options and their effects. [oai_citation_attribution:0‡HexDocs](https://hexdocs.pm/finch/Finch.html?utm_source=chatgpt.com)\n\n- **Error Handling**: Implement appropriate error handling in your application to manage potential issues during HTTP requests, such as network errors or unexpected responses.\n\nBy leveraging Finch, this adapter provides a high-performance HTTP client solution within the Mentor framework, suitable for applications requiring efficient HTTP interactions.","ref":"Mentor.HTTPClient.Finch.html#module-considerations"},{"type":"behaviour","title":"Mentor.LLM.Adapter","doc":"Defines the behaviour for Large Language Model (LLM) adapters within the Mentor framework.\n\nThis module specifies the required callbacks that any LLM adapter must implement to integrate seamlessly with Mentor. It also provides utility functions to assist in verifying and using these adapters.","ref":"Mentor.LLM.Adapter.html"},{"type":"behaviour","title":"Callbacks - Mentor.LLM.Adapter","doc":"- `complete/1`: Processes a `Mentor` struct and returns a result.\n- `complete!/1`: Similar to `complete/1` but raises an exception in case of an error.","ref":"Mentor.LLM.Adapter.html#module-callbacks"},{"type":"behaviour","title":"Usage - Mentor.LLM.Adapter","doc":"To create a custom LLM adapter, define a module that implements the `Mentor.LLM.Adapter` behaviour:\n\n    defmodule MyApp.LLM.CustomAdapter do\n      use Mentor.LLM.Adapter\n\n      @impl true\n      def complete(%Mentor{} = mentor) do\n        # Implementation for processing the mentor struct\n      end\n    end\n\n`complete!/1` is automatic derived and implemented for you, but you can safely override it if needed.\n\nBy implementing these callbacks, your custom adapter can be utilized within the Mentor framework to handle LLM interactions.","ref":"Mentor.LLM.Adapter.html#module-usage"},{"type":"macro","title":"Mentor.LLM.Adapter.__using__/1","doc":"Macro to be used when implementing the `Mentor.LLM.Adapter` behaviour.\n\nThis macro sets up the necessary boilerplate for defining an adapter, including the `@behaviour` attribute and a default implementation for `complete!/1` that raises an exception on error.","ref":"Mentor.LLM.Adapter.html#__using__/1"},{"type":"macro","title":"Usage - Mentor.LLM.Adapter.__using__/1","doc":"defmodule MyApp.LLM.CustomAdapter do\n      use Mentor.LLM.Adapter\n\n      @impl true\n      def complete(%Mentor{} = mentor) do\n        # Implementation for processing the mentor struct\n      end\n    end\n\nBy using this macro, your module declares adherence to the `Mentor.LLM.Adapter` behaviour and provides a default implementation for `complete!/1`.","ref":"Mentor.LLM.Adapter.html#__using__/1-usage"},{"type":"callback","title":"Mentor.LLM.Adapter.complete/1","doc":"Callback to process a `Mentor` struct and return a result.","ref":"Mentor.LLM.Adapter.html#c:complete/1"},{"type":"callback","title":"Parameters - Mentor.LLM.Adapter.complete/1","doc":"- `mentor`: A `Mentor` struct containing the state and configuration for the LLM interaction.","ref":"Mentor.LLM.Adapter.html#c:complete/1-parameters"},{"type":"callback","title":"Returns - Mentor.LLM.Adapter.complete/1","doc":"- `{:ok, result}`: On successful processing.\n- `{:error, reason}`: If an error occurs during processing.\n\nImplement this callback in your adapter module to define how the LLM interaction should be handled.","ref":"Mentor.LLM.Adapter.html#c:complete/1-returns"},{"type":"callback","title":"Mentor.LLM.Adapter.complete!/1","doc":"","ref":"Mentor.LLM.Adapter.html#c:complete!/1"},{"type":"function","title":"Mentor.LLM.Adapter.impl_by?/1","doc":"Checks if the given module implements the `Mentor.LLM.Adapter` behaviour.","ref":"Mentor.LLM.Adapter.html#impl_by?/1"},{"type":"function","title":"Parameters - Mentor.LLM.Adapter.impl_by?/1","doc":"- `module`: The module to be checked.","ref":"Mentor.LLM.Adapter.html#impl_by?/1-parameters"},{"type":"function","title":"Returns - Mentor.LLM.Adapter.impl_by?/1","doc":"- `true` if the module implements the behaviour.\n- `false` otherwise.","ref":"Mentor.LLM.Adapter.html#impl_by?/1-returns"},{"type":"function","title":"Examples - Mentor.LLM.Adapter.impl_by?/1","doc":"iex> Mentor.LLM.Adapter.impl_by?(MyApp.LLM.CustomAdapter)\n    true\n\n    iex> Mentor.LLM.Adapter.impl_by?(String)\n    false","ref":"Mentor.LLM.Adapter.html#impl_by?/1-examples"},{"type":"module","title":"Mentor.LLM.Adapters.OpenAI","doc":"An adapter for integrating OpenAI's language models with the Mentor framework.\n\nThis module implements the `Mentor.LLM.Adapter` behaviour, enabling communication between Mentor and OpenAI's API. It facilitates sending prompts and receiving responses, ensuring compatibility with Mentor's expected data structures.","ref":"Mentor.LLM.Adapters.OpenAI.html"},{"type":"module","title":"Options - Mentor.LLM.Adapters.OpenAI","doc":"* `:url` (`t:String.t/0`) - API endpoint to use for sending requests The default value is `\"https://api.openai.com/v1/chat/completions\"`.\n\n* `:api_key` (`t:String.t/0`) - Required. OpenAI API key\n\n* `:model` - Required. The OpenAI model to query on, known models are: `[\"gpt-4o\", \"gpt-4o-mini\", \"o1\", \"o1-mini\", \"o1-preview\", \"chatgpt-4o-latest\",\n   \"gpt-4o-realtime-preview\", \"gpt-4o-mini-realtime-preview\",\n   \"gpt-4o-audio-preview\"]`","ref":"Mentor.LLM.Adapters.OpenAI.html#module-options"},{"type":"module","title":"Usage - Mentor.LLM.Adapters.OpenAI","doc":"To utilize this adapter, configure your `Mentor` instance with the appropriate options:\n\n    config = [\n      url: \"https://api.openai.com/v1/chat/completions\",\n      api_key: System.get_env(\"OPENAI_API_KEY\"),\n      model: \"gpt-4o\"\n    ]\n\n    mentor = Mentor.start_chat_with!(Mentor.LLM.Adapters.OpenAI, adapter_config: config)","ref":"Mentor.LLM.Adapters.OpenAI.html#module-usage"},{"type":"module","title":"Considerations - Mentor.LLM.Adapters.OpenAI","doc":"- **API Key Security**: Ensure your OpenAI API key is stored securely and not exposed in your codebase.\n- **Model Availability**: Verify that the specified model is available and suitable for your use case. Refer to OpenAI's official documentation for the most up-to-date list of models and their capabilities.\n- **Error Handling**: The `complete/1` function returns `{:ok, response}` on success or `{:error, reason}` on failure. Implement appropriate error handling in your application to manage these scenarios.\n\nBy adhering to the `Mentor.LLM.Adapter` behaviour, this module ensures seamless integration with OpenAI's API, allowing for efficient and effective language model interactions within the Mentor framework.","ref":"Mentor.LLM.Adapters.OpenAI.html#module-considerations"},{"type":"function","title":"Mentor.LLM.Adapters.OpenAI.complete!/1","doc":"Same as `complete/1` but raises an exception in case of error","ref":"Mentor.LLM.Adapters.OpenAI.html#complete!/1"},{"type":"module","title":"Mentor.Parser","doc":"A minimal \"Markdown\" parser to extract structured field documentation from @moduledoc.\nUsed for `Mentor.Ecto.Schema`.\n\nSupports:\n  - `","ref":"Mentor.Parser.html"},{"type":"module","title":"Fields` section (case-sensitive) - Mentor.Parser","doc":"- Field definitions in the format: `- `field_name`: Description`\n  - Multiline descriptions, which are joined as a single paragraph","ref":"Mentor.Parser.html#module-fields-section-case-sensitive"},{"type":"type","title":"Mentor.Parser.ast/0","doc":"","ref":"Mentor.Parser.html#t:ast/0"},{"type":"type","title":"Mentor.Parser.field/0","doc":"","ref":"Mentor.Parser.html#t:field/0"},{"type":"function","title":"Mentor.Parser.run/1","doc":"Parses a Markdown string into an AST-like structure.","ref":"Mentor.Parser.html#run/1"},{"type":"function","title":"Supported Syntax - Mentor.Parser.run/1","doc":"- Sections: `","ref":"Mentor.Parser.html#run/1-supported-syntax"},{"type":"function","title":"Section Title` - Mentor.Parser.run/1","doc":"- Field Definitions: `- `field_name`: Description`\n  - Multiline field descriptions (joined as a single paragraph)","ref":"Mentor.Parser.html#run/1-section-title"},{"type":"function","title":"Returns - Mentor.Parser.run/1","doc":"- `{:ok, ast}` on success\n  - `{:error, reason}` on invalid syntax","ref":"Mentor.Parser.html#run/1-returns"},{"type":"function","title":"Examples - Mentor.Parser.run/1","doc":"iex> markdown = \"\"\"\n    ...>","ref":"Mentor.Parser.html#run/1-examples"},{"type":"function","title":"Fields - Mentor.Parser.run/1","doc":"...> - `name`: The user's name.\n    ...> - `age`: The user's age\n    ...> that defines the user age\n    ...> \"\"\"\n    iex> Mentor.Parser.run(markdown)\n    [{:section, \"Fields\", [{:field, :name, \"The user's name.\"}, {:field, :age, \"The user's age that defines the user age\"}]}]","ref":"Mentor.Parser.html#run/1-fields"},{"type":"type","title":"Mentor.Parser.section/0","doc":"","ref":"Mentor.Parser.html#t:section/0"},{"type":"extras","title":"Mentor","doc":"# Mentor\n\nBecause we love composability!\n\nNo magic, but a higher-level API to generate structed output based on a \"schema\", it can be:\n- a raw map/struct/data structure (string, tuple and so on)\n- an `Ecto` schema (embedded, database or schemaless changesets)\n- a `peri` schema definition","ref":"readme.html"},{"type":"extras","title":"Installation - Mentor","doc":"```elixir\ndef deps do\n  [\n    {:mentor, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"References - Mentor","doc":"- [OpenAI text generation docs](https://platform.openai.com/docs/guides/text-generation)\n- [OpenAI structured outputs docs](https://platform.openai.com/docs/guides/structured-outputs)\n- [OpenAI input formatting cookbook](https://cookbook.openai.com/examples/how_to_format_inputs_to_chatgpt_models)\n- [Anthropic Message format](https://docs.anthropic.com/en/api/messages#body-messages)","ref":"readme.html#references"},{"type":"extras","title":"Spiritual inspirations - Mentor","doc":"- [instructor_ex](https://hexdocs.pm/instructor)\n- [instructor_lite](https://hexdocs.pm/instructor_lite)","ref":"readme.html#spiritual-inspirations"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}